getState<T> method
if you have multiple objects of save type you can use this final state = states.getState
Implementation
T getState<T>(int index) {
return _stats[index];
}
if you have multiple objects of save type you can use this final state = states.getState
T getState<T>(int index) {
return _stats[index];
}